@@ -2,9 +2,9 @@
 ##'
 ##' @description Generates thornthwaite aridity index raster.
 ##'
-##' @param precipStack rasterStack of monthly precipitation.
+##' @param precipStack SpatRaster of monthly precipitation.
 ##'
-##' @param PETstack rasterStack of monthly potential evapotranspiration. 
+##' @param PETstack SpatRaster of monthly potential evapotranspiration. 
 ##' 	Layer names are assumed to end in the month number. 
 ##'
 ##'	@param precipScale integer; scaling factor for the precipitation data, see \link{envirem}
@@ -28,7 +28,7 @@
 ##' \donttest{
 ##' # Find example rasters
 ##' rasterFiles <- list.files(system.file('extdata', package='envirem'), full.names=TRUE)
-##' env <- stack(rasterFiles)
+##' env <- rast(rasterFiles)
 ##'
 ##' # identify the appropriate layers
 ##' meantemp <- grep('mean', names(env), value=TRUE)
@@ -36,18 +36,18 @@
 ##' maxtemp <- grep('tmax', names(env), value=TRUE)
 ##' mintemp <- grep('tmin', names(env), value=TRUE)
 ##' 
-##' # read them in as rasterStacks
-##' meantemp <- stack(env[[meantemp]])
-##' solar <- stack(env[[solar]])
-##' maxtemp <- stack(env[[maxtemp]])
-##' mintemp <- stack(env[[mintemp]])
+##' # read them in as SpatRasters
+##' meantemp <- env[[meantemp]]
+##' solar <- env[[solar]]
+##' maxtemp <- env[[maxtemp]]
+##' mintemp <- env[[mintemp]]
 ##' tempRange <- abs(maxtemp - mintemp)
 ##' 
 ##' # get monthly PET
 ##' pet <- monthlyPET(meantemp, solar, tempRange)
 ##'
 ##' precip <- grep('prec', names(env), value=TRUE)
-##' precip <- stack(env[[precip]])
+##' precip <- env[[precip]]
 ##' 
 ##' # set up naming scheme - only precip is different from default
 ##' assignNames(precip = 'prec_##')
@@ -70,37 +70,37 @@ aridityIndexThornthwaite <- function(precipStack, PETstack, precipScale = 1) {
 
 	#enforce ordering of stack according to numbers in names
 	precipStack <- precipStack[[order(as.numeric(gsub(paste0(.var$precip, '([0-9]+)', .var$precip_post), "\\1", names(precipStack))))]]
-	PETstack <- PETstack[[order(as.numeric(gsub("[a-zA-Z]+_([0-9]+)$", "\\1", names(PETstack))))]]
-
+	PETstack <- PETstack[[order(as.numeric(gsub(paste0(.var$pet, '([0-9]+)', .var$pet_post), "\\1", names(PETstack))))]]
+	
 	if (precipScale != 1) {
 		precipStack <- precipStack / precipScale
 	}
 
 	#create receiving rasters
 	d <- precipStack[[1]]
-	raster::values(d)[!is.na(raster::values(d))] <- 0
+	terra::values(d)[!is.na(terra::values(d))] <- 0
 	n <- precipStack[[1]]
-	raster::values(n)[!is.na(raster::values(n))] <- 0
+	terra::values(n)[!is.na(terra::values(n))] <- 0
 
 	# for each month, determine which cells have precip < PET
-	# for those cells, add value of diff to receiver raster s
+	# for those cells, add value of diff to receiver rasters
 	# for those cells, add PET to n
 	for (i in 1:12) {
 		
 		isPrecipLess <- precipStack[[i]] < PETstack[[i]]
-		cells <- which(raster::values(isPrecipLess) == 0)
+		cells <- which(terra::values(isPrecipLess) == 0)
 		tmp <- PETstack[[i]] - precipStack[[i]]
 		tmp[cells] <- 0
 		d <- d + tmp
 
 		tmp <- PETstack[[i]]
-		raster::values(tmp)[cells] <- 0
+		terra::values(tmp)[cells] <- 0
 		n <- n + tmp
 	}
 
 	res <- 100*d
 	res <- res / n
-	nzeroes <- which(raster::values(n) == 0)
+	nzeroes <- which(terra::values(n) == 0)
 	res[nzeroes] <- 0
 	names(res) <- 'aridityIndexThornthwaite'
 	return(res)
