@@ -1,4 +1,4 @@
-##' @export
+
 
 # define a custom environment for defining the naming of variables
 
@@ -12,6 +12,7 @@ assign('tmax', 'tmax_', envir = .var)
 assign('tmean', 'tmean_', envir = .var)
 assign('precip', 'precip_', envir = .var)
 assign('solrad', 'et_solrad_', envir = .var)
+assign('pet', 'PET_', envir = .var)
 
 assign('bio_post', '', envir = .var)
 assign('tmin_post', '', envir = .var)
@@ -19,6 +20,7 @@ assign('tmax_post', '', envir = .var)
 assign('tmean_post', '', envir = .var)
 assign('precip_post', '', envir = .var)
 assign('solrad_post', '', envir = .var)
+assign('pet_post', '', envir = .var)
 
 
 # ls(envir = .var)
